==> com.liferay.dynamic.data.mapping.form.renderer-3.0.6-sources.jar: META-INF/resources/js/field_events_support.js <==
AUI.add(
	'liferay-ddm-form-renderer-field-events',
	function(A) {
		var FieldEventsSupport = function() {
		};

		FieldEventsSupport.prototype = {
			initializer: function() {
				var instance = this;

				instance._eventHandlers.push(
					instance.after(instance._afterEventsRender, instance, 'render')
				);

				instance._domEvents = [];
			},

			bindContainerEvent: function(eventName, callback, selector, volatile) {
				var instance = this;

				var container = instance.get('container');

				var query = selector;

				if (query.call) {
					query = query.call(instance);
				}

				var handler = container.delegate(eventName, A.bind(callback, instance), query);

				instance._domEvents.push(
					{
						callback: callback,
						handler: handler,
						name: eventName,
						selector: selector,
						volatile: volatile
					}
				);

				return handler;
			},

			bindInputEvent: function(eventName, callback, volatile) {
				var instance = this;

				return instance.bindContainerEvent(eventName, callback, instance.getInputSelector, volatile);
			},

			getChangeEventName: function() {
				return 'change';
			},

			_afterEventsRender: function() {
				var instance = this;

				var events = instance._domEvents;

				instance._domEvents = [];

				var length = events.length;

				while (length--) {
					var event = events[length];

					event.handler.detach();

					if (!event.volatile) {
						instance.bindContainerEvent(event.name, event.callback, event.selector);
					}
				}

				instance._bindDefaultEvents();
			},

			_bindDefaultEvents: function() {
				var instance = this;

				instance.bindInputEvent('blur', instance._onInputBlur, true);
				instance.bindInputEvent('focus', instance._onInputFocus, true);
				instance.bindInputEvent(instance.getChangeEventName(), instance._onValueChange, true);
			},

			_fireBlurEvent: function() {
				var instance = this;

				var root = instance.getRoot();

				if (root) {
					var now = new Date();

					Liferay.fire(
						'ddmFieldBlur',
						{
							fieldName: instance.get('fieldName'),
							focusDuration: (now - (instance.get('fieldFocusDate') || now)),
							formId: root.getFormId(),
							page: root.getCurrentPage() || 1
						}
					);
				}
			},

			_fireFocusEvent: function() {
				var instance = this;

				var root = instance.getRoot();

				if (root) {
					instance.set('fieldFocusDate', new Date());

					Liferay.fire(
						'ddmFieldFocus',
						{
							fieldName: instance.get('fieldName'),
							formId: root.getFormId(),
							page: root.getCurrentPage() || 1
						}
					);
				}
			},

			_fireStartedFillingEvent: function() {
				var instance = this;

				if (!instance.get('startedFilling')) {
					instance.set('startedFilling', true);

					var root = instance.getRoot();

					if (root) {
						Liferay.fire(
							'ddmFieldStartedFilling',
							{
								fieldName: instance.get('fieldName'),
								formId: root.getFormId(),
								page: root.getCurrentPage() || 1
							}
						);
					}
				}
			},

			_getEventPayload: function(originalEvent) {
				var instance = this;

				return {
					field: instance,
					originalEvent: originalEvent
				};
			},

			_onInputBlur: function(event) {
				var instance = this;

				instance.fire('blur', instance._getEventPayload(event));

				instance._fireBlurEvent();
			},

			_onInputFocus: function(event) {
				var instance = this;

				instance.fire('focus', instance._getEventPayload(event));

				instance._fireFocusEvent();
			},

			_onValueChange: function(event) {
				var instance = this;

				var value = instance.getValue();

				instance.set('value', value);

				instance._fireStartedFillingEvent();
			}
		};

		Liferay.namespace('DDM.Renderer').FieldEventsSupport = FieldEventsSupport;
	},
	'',
	{
		requires: []
	}
);

==> com.liferay.dynamic.data.mapping.form.renderer-3.0.69-sources.jar: META-INF/resources/js/field_events_support.js <==
AUI.add(
	'liferay-ddm-form-renderer-field-events',
	function(A) {
		var FieldEventsSupport = function() {
		};

		FieldEventsSupport.prototype = {
			initializer: function() {
				var instance = this;

				instance._eventHandlers.push(
					instance.after(instance._afterEventsRender, instance, 'render')
				);

				instance._domEvents = [];
			},

			destructor: function() {
				var instance = this;

				instance._domEvents.forEach(
					function(domEvent) {
						domEvent.handler.detach();
					}
				);

				instance._domEvents = null;
			},

			bindContainerEvent: function(eventName, callback, selector, volatile) {
				var instance = this;

				var container = instance.get('container');

				var query = selector;

				if (query.call) {
					query = query.call(instance);
				}

				var handler = container.delegate(eventName, A.bind(callback, instance), query);

				instance._domEvents.push(
					{
						callback: callback,
						handler: handler,
						name: eventName,
						selector: selector,
						volatile: volatile
					}
				);

				return handler;
			},

			bindInputEvent: function(eventName, callback, volatile) {
				var instance = this;

				return instance.bindContainerEvent(eventName, callback, instance.getInputSelector, volatile);
			},

			getChangeEventName: function() {
				return 'change';
			},

			getFormPageTitle: function(form) {
				var formPageTitle;
				
				if (form) {
					formPageTitle = form.querySelector('.lfr-ddm-form-page.active .lfr-ddm-form-page-title');
				}
				else {
					formPageTitle = document.querySelector('.lfr-ddm-form-page.active .lfr-ddm-form-page-title');
				}

				if(!formPageTitle) {
					return; 
				}

				return formPageTitle.innerText;
			},

			getFormTitle: function(form) {
				var formTitle;

				if (form) {
					formTitle = form.querySelector('[data-form-title]');
				}
				else {
					formTitle = document.querySelector('[data-form-title]');
				}
				
				if(!formTitle) {
					return
				}
				
				return formTitle.innerText;
			},

			_afterEventsRender: function() {
				var instance = this;

				var events = instance._domEvents;

				instance._domEvents = [];

				var length = events.length;

				while (length--) {
					var event = events[length];

					event.handler.detach();

					if (!event.volatile) {
						instance.bindContainerEvent(event.name, event.callback, event.selector);
					}
				}

				instance._bindDefaultEvents();
			},

			_bindDefaultEvents: function() {
				var instance = this;

				instance.bindInputEvent('blur', instance._onInputBlur, true);
				instance.bindInputEvent('focus', instance._onInputFocus, true);
				instance.bindInputEvent(instance.getChangeEventName(), instance._onValueChange, true);
			},

			_fireBlurEvent: function() {
				var instance = this;

				var root = instance.getRoot();

				if (root) {
					var now = new Date();

					var form = document.querySelector('[data-ddmforminstanceid="' + root.getFormId() + '"]');

					Liferay.fire(
						'ddmFieldBlur',
						{
							fieldName: instance.get('fieldName'),
							focusDuration: (now - (instance.get('fieldFocusDate') || now)),
							formId: root.getFormId(),
							formPageTitle: this.getFormPageTitle(form),
							title: this.getFormTitle(form),
							page: root.getCurrentPage() || 1
						}
					);
				}
			},

			_fireFocusEvent: function() {
				var instance = this;

				var root = instance.getRoot();

				if (root) {
					instance.set('fieldFocusDate', new Date());

					var form = document.querySelector('[data-ddmforminstanceid="' + root.getFormId() + '"]');

					Liferay.fire(
						'ddmFieldFocus',
						{
							fieldName: instance.get('fieldName'),
							formId: root.getFormId(),
							formPageTitle: this.getFormPageTitle(form),
							title: this.getFormTitle(form),
							page: root.getCurrentPage() || 1
						}
					);
				}
			},

			_fireStartedFillingEvent: function() {
				var instance = this;

				if (!instance.get('startedFilling')) {
					instance.set('startedFilling', true);

					var root = instance.getRoot();

					if (root) {
						Liferay.fire(
							'ddmFieldStartedFilling',
							{
								fieldName: instance.get('fieldName'),
								formId: root.getFormId(),
								page: root.getCurrentPage() || 1
							}
						);
					}
				}
			},

			_getEventPayload: function(originalEvent) {
				var instance = this;

				return {
					field: instance,
					originalEvent: originalEvent
				};
			},

			_onInputBlur: function(event) {
				var instance = this;

				instance.fire('blur', instance._getEventPayload(event));

				instance._fireBlurEvent();
			},

			_onInputFocus: function(event) {
				var instance = this;

				instance.fire('focus', instance._getEventPayload(event));

				instance._fireFocusEvent();
			},

			_onValueChange: function(event) {
				var instance = this;

				var value = instance.getValue();

				instance.set('value', value);

				instance._fireStartedFillingEvent();
			}
		};

		Liferay.namespace('DDM.Renderer').FieldEventsSupport = FieldEventsSupport;
	},
	'',
	{
		requires: []
	}
);
